function [pval sign]= CPAtest2(loss1,loss2)

% This function performs the asymptotic Conditional Predictive Ability Test
% INPUTS: loss1 and loss2, T * 1 vectors of losses over the out of sample period 
          for the two models under consideration
%         tau, the forecast horizon
%         alpha, nominal risk level: 1%, 5%, 10%
%         choice: 1 if unconditional; 2 if conditional
%
% OUTPUTS: teststat, the test statistic of the conditional predictive ability test
%          critval, the critical value of the test for a 5% level (the test is a chi square)
%          pval, the p-value of the test
%
% Coded by: Raffaella Giacomini, 2003
%
% This code proposes a general framework for out-of-sample predictive 
% ability testing and forecast selection when the model can be misspecified. 
% It can be applied to different types of forecasts issued from both 
% nested and non-nested models using different estimation techniques 
% for a general loss function (chosen by the user). It accommodates both 
% conditional and unconditional evaluation objectives. The null is 
% H0: E( Loss(model A) - Loss(model B) )= 0. The sign of the test-statistics
% indicates which forecast performs better: a positive test-statistic indicates
% that model A forecast produces larger average loss than the model B 
% forecast (model B outperforms model A), while a negative sign 
% indicates the opposite. 
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

choice = 2;
alpha  = 0.05;
tau    = 1;

lossdiff1=loss1-loss2;    % loss diferential 

TT = size(lossdiff1,1);

if choice==1    
    instruments = ones(TT,1); % ht
    lossdiff    = lossdiff1;
    T=TT;
else
    
    instruments=[ones(TT-tau,1) lossdiff1(1:end-tau)];  % ht
    lossdiff=lossdiff1(tau+1:end);  % loss diferential
    T=TT-tau;
end      

% create the regressor matrix given by lossdiff*ht',
% where ht is the matrix of instruments
reg = -999*ones(size(instruments));
for jj = 1:size(instruments,2)
   reg(:,jj) = instruments(:,jj).*lossdiff;
end

if tau == 1  % forecast horizon = 1
   % calculate the test stat as nR^2 from the regression of 
   % one on lossdiff*ht
   res.beta = reg\ones(T,1);  % regression results, 2 parameters 
   err      = ones(T,1)-reg*res.beta;
   r2       = 1-mean(err.^2);
   teststat = T*r2;
   q        = size(reg,2);
   critval  = chi2inv(1-alpha,q);
   pval     = 1 - cdf('chi2',abs(teststat),q);
else
   zbar     = mean(reg)';
   nlags    = tau-1;
   omega    = NeweyWest(reg,nlags);
   teststat = T*zbar'*inv(omega)*zbar;
   q        = size(reg,2);
   critval  = chi2inv(1-alpha,q);
   pval     = 1 - cdf('chi2',abs(teststat),q);
end

av_diff_loss = mean(loss1-loss2);

if av_diff_loss<0;
    sign = '(-)';
elseif av_diff_loss>0;
    sign = '(+)';
end


 